@@ -33,26 +33,18 @@ class MessageFactory(object):
                 return Message(incoming_string)
 
 class MessageBase(object):
-    TO_PYTHON = {
+    MAPPINGS = {
             '\\\\': '\\',
             '\\/': '/',
-            '\\p': '|',
-            '\\n': '\n',
-            '\\r': '\n',
-            '\\f': '\n',
-            '\\t': '\t',
             '\\s': ' ',
-            '\\v': '',
-            '\\a': '',
-            '\\b': '',
-            }
-    FROM_PYTHON = {
-            '\\': '\\\\',
-            '/': '\\/',
-            '|': '\\p',
-            '\n': '\\n',
-            '\t': '\\t',
-            ' ': '\\s',
+            '\\p': '|',
+            '\\a': '\a',
+            '\\b': '\b',
+            '\\f': '\f',
+            '\\n': '\n',
+            '\\r': '\r',
+            '\\t': '\t',
+            '\\v': '\v',
             }
 
     def __eq__(self, other):
@@ -79,15 +71,15 @@ class MessageBase(object):
                 )
         return tuple(items)
 
-    def _substitute_using_dictionary(self, dictionary, text):
-        pattern = "(%s)" % "|".join(map(re.escape, dictionary.keys()))
-        return re.sub(pattern, lambda k: dictionary[k.group()], text)
-
     def _clean_incoming_value(self, value):
-        return self._substitute_using_dictionary(self.TO_PYTHON, value)
+        return re.sub(r'(\\.)', r'%(\1)s', value) % self.MAPPINGS
 
     def _clean_outgoing_value(self, value):
-        return self._substitute_using_dictionary(self.FROM_PYTHON, value)
+        value = str(value)
+        for fr, to in self.MAPPINGS.items():
+            if to:
+                value = value.replace(to, fr)
+        return value
 
     @property
     def ultimate_origination(self):
